@@ -41,7 +41,11 @@ from caosdb.exceptions import (CaosDBException, HTTPClientError,
                                HTTPResourceNotFoundError,
                                HTTPServerError,
                                HTTPURITooLongError)
-from caosdb.version import version
+try:
+    from caosdb.version import version
+except ModuleNotFoundError:
+    version = "uninstalled"
+
 from pkg_resources import resource_filename
 
 from .interface import CaosDBHTTPResponse, CaosDBServerConnection
@@ -56,7 +60,7 @@ except ImportError:
 
 # pylint: disable=missing-docstring
 
-_LOGGER = logging.getLogger("connection")
+_LOGGER = logging.getLogger(__name__)
 
 
 class _WrappedHTTPResponse(CaosDBHTTPResponse):
